@@ -103,49 +103,53 @@ public class vtkImageViewer extends vtkObject
     return (vtkRenderWindow)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
 }
 
-  private native long GetRenderer_22();
+  private native void SetRenderWindow_22(vtkRenderWindow id0);
+  public void SetRenderWindow(vtkRenderWindow id0)
+    { SetRenderWindow_22(id0); }
+
+  private native long GetRenderer_23();
   public vtkRenderer GetRenderer() {
-    long temp = GetRenderer_22();
+    long temp = GetRenderer_23();
 
     if (temp == 0) return null;
     return (vtkRenderer)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
 }
 
-  private native long GetImageMapper_23();
+  private native long GetImageMapper_24();
   public vtkImageMapper GetImageMapper() {
-    long temp = GetImageMapper_23();
+    long temp = GetImageMapper_24();
 
     if (temp == 0) return null;
     return (vtkImageMapper)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
 }
 
-  private native long GetActor2D_24();
+  private native long GetActor2D_25();
   public vtkActor2D GetActor2D() {
-    long temp = GetActor2D_24();
+    long temp = GetActor2D_25();
 
     if (temp == 0) return null;
     return (vtkActor2D)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
 }
 
-  private native void SetupInteractor_25(vtkRenderWindowInteractor id0);
+  private native void SetupInteractor_26(vtkRenderWindowInteractor id0);
   public void SetupInteractor(vtkRenderWindowInteractor id0)
-    { SetupInteractor_25(id0); }
+    { SetupInteractor_26(id0); }
 
-  private native void SetOffScreenRendering_26(int id0);
+  private native void SetOffScreenRendering_27(int id0);
   public void SetOffScreenRendering(int id0)
-    { SetOffScreenRendering_26(id0); }
+    { SetOffScreenRendering_27(id0); }
 
-  private native int GetOffScreenRendering_27();
+  private native int GetOffScreenRendering_28();
   public int GetOffScreenRendering()
-    { return GetOffScreenRendering_27(); }
+    { return GetOffScreenRendering_28(); }
 
-  private native void OffScreenRenderingOn_28();
+  private native void OffScreenRenderingOn_29();
   public void OffScreenRenderingOn()
-    { OffScreenRenderingOn_28(); }
+    { OffScreenRenderingOn_29(); }
 
-  private native void OffScreenRenderingOff_29();
+  private native void OffScreenRenderingOff_30();
   public void OffScreenRenderingOff()
-    { OffScreenRenderingOff_29(); }
+    { OffScreenRenderingOff_30(); }
 
   public vtkImageViewer() { super(); }
 
